;                Tiny fractal example
;           by Tomasz Slanina  dox@dc-s.com

;  v 1.1 Now works correctly on real hardware (thanks to Jeff Frohwein)
;  v 1.0 gfx glitches on ngpc


;  JULIA SET
;
;  W(z)=z^2+c (z is complex)
;
;  x=Re(z)
;  y=Im(z)
;
;  for y
;   for x
;     x=x.old ^ 2 - y.old ^ 2 +c1
;     y=2 * x.old * y.old + c2


        include "hardware.inc"  ; Include hardware defines
        include "system.inc"    ; Include System Call defines

        cpu     93C141          ; Select Toshiba TLCS-900/H cpu
        maxmode on
        org     200000h


        DB      " LICENSED BY SNK CORPORATION"
        DD      Start   ; Start location
        DW      0       ; Cart ID Code (Catalog number?)
        DB      0       ; Cart Version
        DB      10h     ; System code (Monochrome = 0x00 / Color = 0x10)
        DB      "  FRACTAL   " ; Cart title (12 characters)
        DD      0,0,0,0 ; Reserved

Start:
        calr OS_VERSION  ; Initialize NGP or NGPC mode
        set 6,(rUSERA)   ; User Answer

        ld xwa, VBlankInt
        ld (rVBI), xwa

        ld xhl,kolory-2  ; first palette
        ld xde,_SCR1PAL
        ld xbc,64
        ldirw

        ld xhl,_TILERAM  ; clear tile RAM
        ld xde,_TILERAM+2
        ld xbc,(16*512)/2-1
        ldw (xhl),0
        ldirw

        ld xhl,mapa
        ld xde,_SCR1RAM
        ld xbc,32*32
        ldirw

        ldw     (rWSIH),SCRN_X
        ldw     (rWSIV),SCRN_Y
        ei      0

        xor b,b          ; y
f_y:
        xor c,c          ; x
f_x:
        push bc
        ld d,c
        sub d,80
        xor e,e
        sra 6,de
        ld ix,de         ; X
        ld d,b
        sub d,72
        xor e,e
        sra 6,de
        ld iy,de         ; Y
        ld w,16          ; max iter.
f_inner:
        ld hl,iy         ; Y
        muls xhl,hl      ; signed mul Y*Y
        srl 8,xhl        ; result/256
        ld de,hl         ; YY
        ld bc,ix         ; X
        push bc
        muls xbc,bc      ; signed mul X*X
        srl 8,xbc        ; result/256
        pop hl           ; hl=X
        muls xhl,iy ; signed mul X*Y
        srl 7,xhl        ; result/128 (2*XY)
        add hl,-192
        ld iy,hl         ; new Y
        push bc
        sub bc,de        ; XX - YY
        sub bc,64
        ld ix,bc         ; new X
        pop hl           ; de = XX
        add hl,de        ; XX + YY
        sub hl,4*256
        jr c,no_plot
        ld a,16
        sub a,w
        srl 2,a
        pop bc
        push bc
        call plot        ; PLOT (x,y, (iter>>2))
        jr next
no_plot:
        djnz w,f_inner
next:
        pop bc
        inc c            ; inc x
        cp c,160         ; max x
        jp nz,f_x
        inc b            ; inc y
        cp b,152         ; max y
        jp nz,f_y

end:
        jr end

plot:
       inc a
       cp a,4
       jr c,col_ok
       ld a,3
col_ok:
       xor xde,xde
       ld e,b
       srl 2,e
       res 0,e           ; (y>>3)*2
       ld xhl,plottable
       add xde,xhl
       xor xhl,xhl
       ld hl,(xde)       ; (y>>3)*20*16
       ld xde,_TILERAM
       add xhl,xde
       ld e,c
       and xde,248       ;
       sla xde           ; (x>>3)*16
       add xhl,xde       ; tile address in RAM
       ld e,b
       and xde,7         ; (x%8)*2
       add xde,xde
       add xhl,xde       ; tile row
       bit 2,c           ; hi/lo
       jr nz,niezw
       inc xhl
niezw:
       and c,3           ; pixel bits
       ld b,3
       sub b,c
       jr z,put
kka:
       sla 2,a
       dec b
       jr nz,kka
put:
       or (xhl),a        ; set pixel
       ret

VBlankInt:
        ld      (rWDT),WDT_UPDATE
        reti

kolory:
        RGBSet 40,40,80
        RGBSet 100,100,160
        RGBSet 140,140,255

SYSTEM_CALL:
       SystemCallCode
OS_VERSION:
       OsVersionCode

mapa:
      include "mapa.inc"

plottable:
      dw 0,320,640,960,1280,1600,1920,2240,2560,2880,3200
      dw 3520,3840,4160,4480,4800,5120,5440,5760

    END
