; *
; * NGPC Register Defines
; *
; * by Jeff Frohwein
; *
; * v1.0 - Original release, 00-Apr-17
; *

rWDT    equ     $6f     ; Watch Dog Timer
WDT_UPDATE equ    $4e   ;  Value required to be written to rWDT

rBV     equ     $6F80   ; Battery Voltage
rSL     equ     $6F82   ; Sys Lever (Controller Input)
rUSERB  equ     $6F84   ; User Boot
rUSERS  equ     $6F85   ; User Shutdown
rUSERA  equ     $6F86   ; User Answer
rLANG   equ     $6F87   ; Language
rOSV    equ     $6F91   ; OS Version

; User Program Interrupt Vectors

rSWI3   equ     $6FB8   ; Software Interrupt (SWI 3)
rSWI4   equ     $6FBC   ; Software Interrupt (SWI 4)
rSWI5   equ     $6FC0   ; Software Interrupt (SWI 5)
rSWI6   equ     $6FC4   ; Software Interrupt (SWI 6)
rRTCI   equ     $6FC8   ; RTC Alarm Interrupt
rVBI    equ     $6FCC   ; Vertical Blanking Interrupt
rZ80I   equ     $6FD0   ; Interrupt from Z80
rTI0    equ     $6FD4   ; Timer Interrupt (8 bit timer 0)
rTI1    equ     $6FD8   ; Timer Interrupt (8 bit timer 1)
rTI2    equ     $6FDC   ; Timer Interrupt (8 bit timer 2)
rTI3    equ     $6FE0   ; Timer Interrupt (8 bit timer 3)
rSTI    equ     $6FE4   ; Serial Transmission Interrupt
rSRI    equ     $6FE8   ; Serial Reception Interrupt
rEMDMA0 equ     $6FF0   ; End Micro DMA Int (MicroDMA 0)
rEMDMA1 equ     $6FF4   ; End Micro DMA Int (MicroDMA 1)
rEMDMA2 equ     $6FF8   ; End Micro DMA Int (MicroDMA 2)
rEMDMA3 equ     $6FFC   ; End Micro DMA Int (MicroDMA 3)

; Window Registers

rWBAH   equ     $8002   ; WBA.H = Window Horizontal Origin
rWBAV   equ     $8003   ; WBA.V = Window Vertical Origin
rWSIH   equ     $8004   ; WSI.H = Window X Size
rWSIV   equ     $8005   ; WSI.V = Window Y Size

; Frame Rate Register

rREF    equ     $8006   ; REF = Frame Rate Register

; Raster Position Registers

rRASH   equ     $8008   ; RAS.H = Raster Position Horizontal
rRASV   equ     $8009   ; RAS.V = Raster Position Vertical

; 2D Status Register

r2DSR   equ     $8010   ; Character Over / Vblank Status

; 2D Control Register

r2DCR   equ     $8012   ; NEG / OOWC Setting

; Sprite Position Offset

rPOH    equ     $8020   ; PO.H = Position Offset Horizontal
rPOV    equ     $8021   ; PO.V = Position Offset Vertical

; Scroll Plane Priority Function

rPF     equ     $8030   ; Scroll plane 1 in front/back

; Scroll Offset Registers

rS1SOH  equ     $8032   ; S1SO.H = Scroll Plane 1 X Scroll Offset
rS1SOV  equ     $8033   ; S1SO.V = Scroll Plane 1 Y Scroll Offset
rS2SOH  equ     $8034   ; S2SO.H = Scroll Plane 2 X Scroll Offset
rS2SOV  equ     $8035   ; S2SO.V = Scroll Plane 2 Y Scroll Offset

; Colo(u)r Palette RAM

_SPRPAL  equ     $8200   ; Sprite palettes (K2GE)
_SCR1PAL equ     $8280   ; Scroll 1 palettes (K2GE)
_SCR2PAL equ     $8300   ; Scroll 2 palettes (K2GE)
_BGCPAL  equ     $83E0   ; Background Colo(u)r Palettes
_WCPAL   equ     $83F0   ; Window Colo(u)r Palettes

; Background Colo(u)r Register

rBCR    equ     $8118   ; BGON / BGC Settings

; Mode Selection Register

rMSR    equ     $87E2   ; MODE (K1GE/K2GE Select)

; RAM Equates

_MAINRAM equ    $4000   ; Main work RAM Start Address
_SPRRAM equ     $8800   ; Sprite VRAM Start Address
_SCR1RAM equ    $9000   ; Scroll 1 VRAM Start Address
_SCR2RAM equ    $9800   ; Scroll 2 VRAM Start Address
_TILERAM equ    $A000   ; Sprite/Scroll Tileset Start Address

_INTROM equ     $ff0000 ; Internal ROM Start Address

; Screen Defines

SCRN_X     EQU  160 ; Width of screen in pixels
SCRN_Y     EQU  152 ; Height of screen in pixels
SCRN_X_B   EQU  20  ; Width of screen in bytes
SCRN_Y_B   EQU  19  ; Height of screen in bytes

SCRN_VX    EQU  256 ; Virtual width of screen in pixels
SCRN_VY    EQU  256 ; Virtual height of screen in pixels
SCRN_VX_B  EQU  64  ; Virtual width of screen in bytes
SCRN_VY_B  EQU  64  ; Virtual height of screen in bytes

; This macro accept RGB values from 0-255 in R,G,B Format

RGBSet: MACRO parR,parG,parB
        DW      ((parB >> 4) << 8) + ((parG >> 4) << 4) + (parR >> 4)
        ENDM

; Main RAM Definition Macros

RAMDB:  MACRO para
para    equ   START_OF_RAM
START_OF_RAM SET START_OF_RAM+1
        ENDM

RAMDW:  MACRO para
para    equ   START_OF_RAM
START_OF_RAM SET START_OF_RAM+2
        ENDM

RAMDD:  MACRO para
para    equ   START_OF_RAM
START_OF_RAM SET START_OF_RAM+4
        ENDM