;*
;*
;* System Call Functions
;*
;* by Jeff Frohwein, 00-Apr-16
;*
;* Version 1.0 - Original release

; $99 = Currently Unknown

VECT_SHUTDOWN          equ     0       ; Shutdown (Power OFF)
VECT_CLOCKGEARSET      equ     $99       ; CPU operation clock setting
VECT_INTLVSET          equ     $99       ; Interrupt level setting
VECT_RTCGET            equ     2       ; Real time clock - obtain time
VECT_ALARMSET          equ     $99       ; Real time clock - alarm setting during game operation
VECT_ALARMDOWNSET      equ     $99       ; Real time clock - unit start up alarm setting
VECT_SYSFONTSET        equ     5       ; System font setting
VECT_FLASHWRITE        equ     $99       ; Flash memory - data write
VECT_FLASHALLERS       equ     $99       ; Flash memory - erase all blocks
VECT_FLASHERS          equ     $99       ; Flash memory - erase specified blocks
VECT_FLASHPROTECT      equ     $99       ; Flash memory - protect specified blocks
VECT_GEMODESET         equ     $99       ; Color LCD color mode setting (color version only)

; (Serial Communication)

VECT_COMINIT           equ     $99       ; Initialize serial communication BIOS
VECT_COMSENDSTART      equ     $99       ; Communication start send BIOS
VECT_COMRECIVESTART    equ     $99       ; Communication start reception BIOS
VECT_COMCREATEDATA     equ     $99       ; Communication create send data BIOS
VECT_COMGETDATA        equ     $99       ; Communication obtain reception data BIOS
VECT_COMONRTS          equ     $99       ; Communication allow RTS signal send BIOS
VECT_COMOFFRTS         equ     $99       ; Communication prohibit RTS signal send BIOS
VECT_COMSENDSTATUS     equ     $99       ; Communication obtain send status BIOS
VECT_COMRECIVESTATUS   equ     $99       ; Communication obtain reception status BIOS
VECT_COMCREATEBUFDATA  equ     $99       ; Communication obtain create data buffer BIOS
VECT_COMGETBUFDATA     equ     $99       ; Communication write reception obtaining buffer BIOS

; *** Shutdown (Power OFF) ***
; Entry:
;    rw3 = VECT_SHUTDOWN
;

; *** CPU operation clock setting ***
; Entry:
;    rw3 = VECT_CLOCKGEARSET
;    rb3 = CPU Speed Setting (4 = 384KHz)
;    rc3 = Auto Clock Speed Regeneration (0ffh = off)
; Exit:
;    CPU speed is changed.

; *** Real time clock - obtain time ***
; Entry:
;    rw3 = VECT_RTCGET
;    xhl3 = Pointer to RAM to return time.
; Exit:
;    Values returned in Binary Coded Decimal (BCD).
;    (Ptr+0) = Year  (00h-99h)
;    (Ptr+1) = Month (01h-12h)
;    (Ptr+2) = Day   (01h-31h)
;    (Ptr+3) = Hours (00h-23h)
;    (Ptr+4) = Mins  (00h-59h)
;    (Ptr+5) = Secs  (00h-59h)

; *** System font setting ***
; Entry:
;    rw3 = VECT_SYSFONTSET
;    ra3 = ?
; Exit:
;    Copy system font to Character tile RAM.

SystemCallCode: macro
        push    sr
        ldf     3
        push    xix
        add     w,w
        add     w,w
        ld      xix,0fffe00h
        ld      xix,(xix+w)
        call    (xix)
        pop     xix
        pop     sr
        ret

        endm

; Set NGP or NGPC mode

OsVersionCode: macro
        cp      (rOSV),0
        jr      nz,OSVExit

        res     3,(6f83h)
        ld      (6da0h),0
OSVExit:
        ret

        endm
